@@ -30,35 +30,11 @@ limitations under the License.
 #define CG_SET(x, SYMBOL, v) Rf_defineVar(SYMBOL, v, x)
 
 /*
- * SYMBOLS
+ * PUBLIC FUNCTIONS
  */
 
-SEXP CG_ID_SYMBOL;
-SEXP CG_DEF_SYMBOL;
-SEXP CG_FUN_SYMBOL;
-SEXP CG_GRAD_SYMBOL;
-SEXP CG_NAME_SYMBOL;
-SEXP CG_TYPE_SYMBOL;
-SEXP CG_EAGER_SYMBOL;
-SEXP CG_GRADS_SYMBOL;
-SEXP CG_GRAPH_SYMBOL;
-SEXP CG_NODES_SYMBOL;
-SEXP CG_VALUE_SYMBOL;
-SEXP CG_INPUTS_SYMBOL;
-SEXP CG_SESSION_SYMBOL;
+SEXP cg_class(const char *name);
 
-/*
- * PRIVATE METHODS
- */
-
-int cg_is(SEXP env, const char *class_name);
-
-/*
- * PRIVATE CONSTRUCTORS
- */
-
-SEXP cg_class1(const char *class_name1);
-
-SEXP cg_class2(const char *class_name1, const char *class_name2);
+int cg_is(SEXP env, const char *name);
 
 #endif
