@@ -20,104 +20,24 @@ limitations under the License.
 #include <Rinternals.h>
 
 #include "node.h"
-#include "class.h"
 #include "graph.h"
 #include "stack.h"
 #include "session.h"
 #include "function.h"
 
 /*
- * PRIVATE METHODS
+ * INLINED GET/SET FUNCTIONS
  */
 
-SEXP cg_graph_nodes(SEXP graph)
-{
-  SEXP nodes = PROTECT(CG_GET(graph, CG_NODES_SYMBOL));
+extern inline SEXP cg_graph_nodes(SEXP graph);
 
-  if(TYPEOF(nodes) != VECSXP)
-  {
-    Rf_errorcall(R_NilValue, "graph does not have any nodes");
-  }
+extern inline int cg_graph_eager(SEXP graph);
 
-  UNPROTECT(1);
+extern inline void cg_graph_set_eager(SEXP graph, const int eager);
 
-  return nodes;
-}
-
-int cg_graph_eager(SEXP graph)
-{
-  SEXP eager = PROTECT(CG_GET(graph, CG_EAGER_SYMBOL));
-
-  if(!IS_SCALAR(eager, LGLSXP))
-  {
-    UNPROTECT(1);
-
-    return 1;
-  }
-
-  UNPROTECT(1);
-
-  return INTEGER(eager)[0];
-}
-
-void cg_graph_set_eager(SEXP graph, const int eager)
-{
-  CG_SET(graph, CG_EAGER_SYMBOL, Rf_ScalarLogical(eager));
-}
-
-char* cg_graph_gen_name(SEXP graph)
-{
-  char *name = R_alloc(1, 32 * sizeof(char));
-
-  SEXP nodes = PROTECT(CG_GET(graph, CG_NODES_SYMBOL));
-
-  if(TYPEOF(nodes) != VECSXP)
-  {
-    strcpy(name, "v1");
-  }
-  else
-  {
-    R_len_t n = XLENGTH(nodes);
-
-    sprintf(name, "v%d", n + 1);
-  }
-
-  UNPROTECT(1);
-
-  return name;
-}
-
-void cg_graph_add_node(SEXP graph, SEXP node)
-{
-  int index;
-
-  SEXP nodes = R_NilValue;
-
-  PROTECT_WITH_INDEX(nodes = CG_GET(graph, CG_NODES_SYMBOL), &index);
-
-  if(TYPEOF(nodes) != VECSXP)
-  {
-    REPROTECT(nodes = Rf_allocVector(VECSXP, 1), index);
-
-    SET_VECTOR_ELT(nodes, 0, node);
-
-    cg_node_set_id(node, 1);
-  }
-  else
-  {
-    R_len_t n = XLENGTH(nodes);
-
-    REPROTECT(nodes = Rf_lengthgets(nodes, n + 1), index);
-
-    SET_VECTOR_ELT(nodes, n, node);
-
-    cg_node_set_id(node, n + 1);
-  }
-
-  CG_SET(graph, CG_NODES_SYMBOL, nodes);
-
-  UNPROTECT(1);
-}
+/*
+ * PRIVATE FUNCTIONS
+ */
 
 void cg_graph_dfs_from(SEXP graph, SEXP target, int (*filter)(SEXP node), void (*exec)(SEXP node))
 {
@@ -156,6 +76,12 @@ void cg_graph_dfs_from(SEXP graph, SEXP target, int (*filter)(SEXP node), void (
     {
       SEXP input = VECTOR_ELT(inputs, i);
 
+      if(TYPEOF(input) != ENVSXP)
+      {
+        Rf_errorcall(R_NilValue, "node '%s' has an invalid input at index %d",
+                     cg_node_name(node), i + 1);
+      }
+
       int input_id = cg_node_id(input);
 
       if(input_id < 1 || input_id > n)
@@ -229,6 +155,12 @@ void cg_graph_reverse_dfs_from(SEXP graph, SEXP target, int (*filter)(SEXP node)
     {
       SEXP input = VECTOR_ELT(inputs, i);
 
+      if(TYPEOF(input) != ENVSXP)
+      {
+        Rf_errorcall(R_NilValue, "node '%s' has an invalid input at index %d",
+                     cg_node_name(node), i + 1);
+      }
+
       int input_id = cg_node_id(input);
 
       if(input_id < 1 || input_id > n)
@@ -266,10 +198,42 @@ void cg_graph_reverse_dfs_from(SEXP graph, SEXP target, int (*filter)(SEXP node)
   UNPROTECT(1);
 }
 
+static inline int filter(SEXP node)
+{
+  if(cg_node_type(node) == CGOPR)
+  {
+    return 1;
+  }
+
+  return 0;
+}
+
 /*
- * PUBLIC METHODS
+ * PUBLIC FUNCTIONS
  */
 
+SEXP cg_graph_gen_name(SEXP graph)
+{
+  char *name = R_alloc(1, 32 * sizeof(char));
+
+  SEXP nodes = PROTECT(CG_GET(graph, CG_NODES_SYMBOL));
+
+  if(TYPEOF(nodes) != VECSXP)
+  {
+    strcpy(name, "v1");
+  }
+  else
+  {
+    R_len_t n = XLENGTH(nodes);
+
+    sprintf(name, "v%d", n + 1);
+  }
+
+  UNPROTECT(1);
+
+  return Rf_mkString(name);
+}
+
 SEXP cg_graph_get(SEXP graph, SEXP name)
 {
   if(!cg_is(graph, "cg_graph"))
@@ -306,14 +270,36 @@ SEXP cg_graph_get(SEXP graph, SEXP name)
   Rf_errorcall(R_NilValue, "cannot find node '%s'", pn);
 }
 
-static int filter(SEXP node)
+void cg_graph_add_node(SEXP graph, SEXP node)
 {
-  if(cg_node_type(node) == CGOPR)
+  int index;
+
+  SEXP nodes = R_NilValue;
+
+  PROTECT_WITH_INDEX(nodes = CG_GET(graph, CG_NODES_SYMBOL), &index);
+
+  if(TYPEOF(nodes) != VECSXP)
   {
-    return 1;
+    REPROTECT(nodes = Rf_allocVector(VECSXP, 1), index);
+
+    SET_VECTOR_ELT(nodes, 0, node);
+
+    cg_node_set_id(node, 1);
+  }
+  else
+  {
+    R_len_t n = XLENGTH(nodes);
+
+    REPROTECT(nodes = Rf_lengthgets(nodes, n + 1), index);
+
+    SET_VECTOR_ELT(nodes, n, node);
+
+    cg_node_set_id(node, n + 1);
   }
 
-  return 0;
+  CG_SET(graph, CG_NODES_SYMBOL, nodes);
+
+  UNPROTECT(1);
 }
 
 SEXP cg_graph_forward(SEXP graph, SEXP target)
@@ -426,7 +412,7 @@ SEXP cg_graph(SEXP eager)
     Rf_errorcall(R_NilValue, "argument 'eager' must be a logical scalar");
   }
 
-  SEXP graph = PROTECT(cg_class1("cg_graph"));
+  SEXP graph = PROTECT(cg_class("cg_graph"));
 
   CG_SET(graph, CG_EAGER_SYMBOL, eager);
   CG_SET(graph, CG_NODES_SYMBOL, R_NilValue);
