@@ -22,7 +22,21 @@ limitations under the License.
 #include "stack.h"
 
 /*
- * PUBLIC METHODS
+ * INLINE FUNCTIONS
+ */
+
+extern inline int cg_stack_is_empty(const cg_stack_t *stack);
+
+extern inline int cg_stack_is_full(const cg_stack_t *stack);
+
+extern inline void cg_stack_push(cg_stack_t *stack, const SEXP x);
+
+extern inline SEXP cg_stack_top(const cg_stack_t *stack);
+
+extern inline void cg_stack_pop(cg_stack_t *stack);
+
+/*
+ * PUBLIC CONSTRUCTORS
  */
 
 cg_stack_t* cg_stack_allocate(const int size)
@@ -37,48 +51,3 @@ cg_stack_t* cg_stack_allocate(const int size)
 
   return stack;
 }
-
-int cg_stack_is_empty(const cg_stack_t *stack)
-{
-  return stack->top < 0;
-}
-
-int cg_stack_is_full(const cg_stack_t *stack)
-{
-  return stack->top >= stack->size - 1;
-}
-
-void cg_stack_push(cg_stack_t *stack, const SEXP x)
-{
-  if(cg_stack_is_full(stack))
-  {
-    int size = (stack->size > 0) ? 2 * stack->size : 1;
-
-    SEXP *data = R_Realloc(stack->data, size, SEXP);
-
-    stack->data = data;
-    stack->size = size;
-  }
-
-  stack->data[++stack->top] = x;
-}
-
-SEXP cg_stack_top(const cg_stack_t *stack)
-{
-  if(cg_stack_is_empty(stack))
-  {
-    Rf_errorcall(R_NilValue, "unable to retrieve top element because the stack is empty");
-  }
-
-  return stack->data[stack->top];
-}
-
-void cg_stack_pop(cg_stack_t *stack)
-{
-  if(cg_stack_is_empty(stack))
-  {
-    Rf_errorcall(R_NilValue, "unable to pop the top element because the stack is empty");
-  }
-
-  stack->top--;
-}
